# Welcome!

Welcome to Limbo, a library for working with computer vision data stored using the Limbo Data Format, which we created to organize and annotate the hybrid synthetic training data that we create for our research.

You can see the full Limbo documentation at https://limbo-ml.readthedocs.io ... for questions, comments, or suggestions, get in touch with our team at https://github.com/limbo-ml/user/discussions.

